/*
 * Copyright (c) 2017, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root  or https://opensource.org/licenses/BSD-3-Clause
 */
/* eslint global-require: 0 */
'use strict';
// Node
const path = require('path');
// Local
const messages = require(path.join(__dirname, '..', '..', 'lib', 'messages'))();
const logger = require(path.join(__dirname, '..', '..', 'lib', 'logApi'));
module.exports = function (_execCommand) {
    return {
        description: messages.getMessage('description', [], 'auth_logout'),
        longDescription: messages.getMessage('longDescription', [], 'auth_logout'),
        help: messages.getMessage('help', [], 'auth_logout'),
        requiresProject: false,
        requiresUsername: false,
        supportsTargetUsername: true,
        flags: [
            {
                name: 'all',
                char: 'a',
                description: messages.getMessage('all', [], 'auth_logout'),
                longDescription: messages.getMessage('allLong', [], 'auth_logout'),
                hasValue: false,
                required: false,
                type: 'flag'
            },
            {
                name: 'noprompt',
                char: 'p',
                description: messages.getMessage('noPrompt', [], 'auth_logout'),
                longDescription: messages.getMessage('noPromptLong', [], 'auth_logout'),
                hasValue: false,
                required: false,
                type: 'flag'
            }
        ],
        /**
         * the heroku cli hook
         * @param context - the cli context
         * @returns {*  }
         */
        run(context) {
            const heroku = require('heroku-cli-util');
            const AuthLogoutCommand = require(path.join(__dirname, '..', '..', 'lib', 'authLogoutCommand'));
            const authLogoutCommand = new AuthLogoutCommand();
            if (context.flags.targetusername && context.flags.all) {
                const err = new Error(messages.getMessage('specifiedBothUserAndAllError', [], 'auth_logout'));
                err.name = 'SpecifiedBothUserAndAllError';
                return Promise.reject(err);
            }
            this.logger = logger.child('auth_logout');
            return authLogoutCommand.getOrgsToLogout(context, this.logger)
                .then((orgsToLogout) => {
                context.orgsToLogout = orgsToLogout;
                // don't prompt yes/no if we're forcing the delete request, just execute
                if (context.flags.noprompt || this.logger.getEnvironmentMode().isDemo()) {
                    return _execCommand(authLogoutCommand, context);
                }
                else {
                    return heroku.prompt(messages.getMessage('logoutCommandYesNo', [authLogoutCommand.getStyledList(orgsToLogout)], 'auth_logout'))
                        .then((answer) => {
                        if (answer.toUpperCase() === 'YES' || answer.toUpperCase() === 'Y') {
                            return _execCommand(authLogoutCommand, context);
                        }
                        return undefined;
                    });
                }
            });
        }
    };
};

//# sourceMappingURL=auth_logout.js.map
