/*
 * Copyright (c) 2016, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root  or https://opensource.org/licenses/BSD-3-Clause
 */
/* eslint global-require: 0 */
'use strict';
const path = require('path');
const messages = require(path.join(__dirname, '..', '..', 'lib', 'messages'))();
const constants = require(path.join(__dirname, '..', '..', 'lib', 'constants'));
module.exports = function (_execCommand) {
    return {
        description: messages.getMessage('cliDescription', [], 'package_create'),
        longDescription: messages.getMessage('cliLongDescription', [], 'package_create'),
        help: messages.getMessage('help', [], 'package_create'),
        orgType: constants.DEFAULT_DEV_HUB_USERNAME,
        supportsTargetDevHubUsername: true,
        flags: [
            {
                name: 'name',
                char: 'n',
                description: messages.getMessage('name', [], 'package_create'),
                longDescription: messages.getMessage('nameLong', [], 'package_create'),
                hasValue: true,
                required: true,
                type: 'string'
            },
            {
                name: 'packagetype',
                char: 't',
                description: messages.getMessage('packageType', [], 'package_create'),
                longDescription: messages.getMessage('packageTypeLong', [], 'package_create'),
                hasValue: true,
                required: true,
                type: 'string',
                values: ['Managed', 'Unlocked']
            },
            {
                name: 'description',
                char: 'd',
                description: messages.getMessage('description', [], 'package_create'),
                longDescription: messages.getMessage('descriptionLong', [], 'package_create'),
                hasValue: true,
                required: false,
                type: 'string'
            },
            {
                name: 'nonamespace',
                char: 'e',
                description: messages.getMessage('noNamespace', [], 'package_create'),
                longDescription: messages.getMessage('noNamespaceLong', [], 'package_create'),
                hasValue: false,
                required: false,
                type: 'flag'
            },
            {
                name: 'path',
                char: 'r',
                description: messages.getMessage('path', [], 'package_version_create'),
                longDescription: messages.getMessage('longPath', [], 'package_version_create'),
                hasValue: true,
                required: true,
                type: 'directory'
            }
        ],
        /**
         * the heroku cli hook
         * @param context - the cli context
         * @returns {Promise}
         */
        run(context) {
            const PackageCreateCommand = require(path.join('..', '..', 'lib', 'package', 'packageCreateCommand'));
            return _execCommand(new PackageCreateCommand(), context);
        }
    };
};

//# sourceMappingURL=package_create.js.map
