/*
 * Copyright (c) 2016, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root  or https://opensource.org/licenses/BSD-3-Clause
 */
/* eslint global-require: 0 */
'use strict';
const path = require('path');
const heroku = require('heroku-cli-util');
const messages = require(path.join(__dirname, '..', '..', 'lib', 'messages'))();
module.exports = function (_execCommand) {
    return {
        description: messages.getMessage('cliDescription', [], 'package_install'),
        longDescription: messages.getMessage('cliDescriptionLong', [], 'package_install'),
        help: messages.getMessage('help', [], 'package_install'),
        requiresProject: false,
        supportsTargetUsername: true,
        flags: [
            {
                name: 'id',
                char: 'i',
                description: messages.getMessage('id', [], 'package_install'),
                longDescription: messages.getMessage('idLong', [], 'package_install'),
                hasValue: true,
                required: false,
                type: 'id',
                deprecated: {
                    version: '43.0',
                    to: '--package'
                }
            },
            {
                name: 'wait',
                char: 'w',
                description: messages.getMessage('wait', [], 'package_install'),
                longDescription: messages.getMessage('waitLong', [], 'package_install'),
                hasValue: true,
                required: false,
                type: 'minutes'
            },
            {
                name: 'installationkey',
                char: 'k',
                description: messages.getMessage('installationKey', [], 'package_install'),
                longDescription: messages.getMessage('installationKeyLong', [], 'package_install'),
                hasValue: true,
                required: false,
                type: 'string'
            },
            {
                name: 'publishwait',
                char: 'p',
                description: messages.getMessage('publishWait', [], 'package_install'),
                longDescription: messages.getMessage('publishWaitLong', [], 'package_install'),
                hasValue: true,
                required: false,
                type: 'minutes'
            },
            {
                name: 'noprompt',
                char: 'r',
                description: messages.getMessage('noPrompt', [], 'package_install'),
                longDescription: messages.getMessage('noPromptLong', [], 'package_install'),
                hasValue: false,
                required: false,
                type: 'flag'
            },
            {
                name: 'package',
                char: '',
                description: messages.getMessage('package', [], 'package_install'),
                longDescription: messages.getMessage('packageLong', [], 'package_install'),
                hasValue: true,
                required: false,
                type: 'string'
            }
        ],
        /**
         * the heroku cli hook
         * @param context - the cli context
         * @returns {Promise}
         */
        run(context) {
            const PackageInstallCommand = require(path.join('..', '..', 'lib', 'package', 'packageInstallCommand'));
            return _execCommand(new PackageInstallCommand(heroku.prompt), context);
        }
    };
};

//# sourceMappingURL=package_install.js.map
