/*
 * Copyright (c) 2016, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root  or https://opensource.org/licenses/BSD-3-Clause
 */
/* eslint global-require: 0 */
'use strict';
const path = require('path');
const messages = require(path.join(__dirname, '..', '..', 'lib', 'messages'))();
const constants = require(path.join(__dirname, '..', '..', 'lib', 'constants'));
module.exports = function (_execCommand) {
    return {
        description: messages.getMessage('cliDescription', [], 'package_version_create'),
        longDescription: messages.getMessage('cliLongDescription', [], 'package_version_create'),
        help: messages.getMessage('help', [], 'package_version_create'),
        orgType: constants.DEFAULT_DEV_HUB_USERNAME,
        supportsTargetDevHubUsername: true,
        flags: [
            {
                name: 'package',
                char: 'p',
                description: messages.getMessage('package', [], 'package_version_create'),
                longDescription: messages.getMessage('longPackage', [], 'package_version_create'),
                hasValue: true,
                required: false,
                type: 'string'
            },
            {
                name: 'path',
                char: 'd',
                description: messages.getMessage('path', [], 'package_version_create'),
                longDescription: messages.getMessage('longPath', [], 'package_version_create'),
                hasValue: true,
                required: false,
                type: 'directory'
            },
            {
                name: 'definitionfile',
                char: 'f',
                description: messages.getMessage('definitionfile', [], 'package_version_create'),
                longDescription: messages.getMessage('longDefinitionfile', [], 'package_version_create'),
                hasValue: true,
                required: false,
                type: 'filepath'
            },
            {
                name: 'branch',
                char: 'b',
                description: messages.getMessage('branch', [], 'package_version_create'),
                longDescription: messages.getMessage('longBranch', [], 'package_version_create'),
                hasValue: true,
                required: false,
                type: 'string'
            },
            {
                name: 'tag',
                char: 't',
                description: messages.getMessage('tag', [], 'package_version_create'),
                longDescription: messages.getMessage('longTag', [], 'package_version_create'),
                hasValue: true,
                required: false,
                type: 'string'
            },
            {
                name: 'installationkey',
                char: 'k',
                description: messages.getMessage('key', [], 'package_version_create'),
                longDescription: messages.getMessage('longKey', [], 'package_version_create'),
                hasValue: true,
                required: false,
                type: 'string'
            },
            {
                name: 'installationkeybypass',
                char: 'x',
                description: messages.getMessage('keyBypass', [], 'package_version_create'),
                longDescription: messages.getMessage('longKeyBypass', [], 'package_version_create'),
                hasValue: false,
                required: false,
                type: 'string'
            },
            {
                name: 'preserve',
                char: 'r',
                description: messages.getMessage('preserve', [], 'package_version_create'),
                longDescription: messages.getMessage('longPreserve', [], 'package_version_create'),
                hasValue: false,
                required: false,
                hidden: true,
                type: 'boolean'
            },
            {
                name: 'validateschema',
                char: 'j',
                description: messages.getMessage('validateschema', [], 'package_version_create'),
                longDescription: messages.getMessage('longValidateschema', [], 'package_version_create'),
                hasValue: false,
                required: false,
                hidden: true,
                type: 'boolean'
            },
            {
                name: 'wait',
                char: 'w',
                description: messages.getMessage('wait', [], 'package_version_create'),
                longDescription: messages.getMessage('longWait', [], 'package_version_create'),
                hasValue: true,
                required: false,
                type: 'minutes',
                default: '0'
            },
            {
                name: 'buildinstance',
                char: 's',
                description: messages.getMessage('instance', [], 'package_version_create'),
                longDescription: messages.getMessage('longInstance', [], 'package_version_create'),
                hasValue: true,
                required: false,
                hidden: true,
                type: 'string'
            },
            {
                name: 'sourceorg',
                char: 'o',
                description: messages.getMessage('sourceorg', [], 'package_version_create'),
                longDescription: messages.getMessage('longSourceorg', [], 'package_version_create'),
                hasValue: true,
                required: false,
                hidden: true,
                type: 'string'
            },
            {
                name: 'versionname',
                char: 'a',
                description: messages.getMessage('versionname', [], 'package_version_create'),
                longDescription: messages.getMessage('longVersionname', [], 'package_version_create'),
                hasValue: true,
                required: false,
                type: 'string'
            },
            {
                name: 'versionnumber',
                char: 'n',
                description: messages.getMessage('versionnumber', [], 'package_version_create'),
                longDescription: messages.getMessage('longVersionnumber', [], 'package_version_create'),
                hasValue: true,
                required: false,
                type: 'string'
            },
            {
                name: 'versiondescription',
                char: 'e',
                description: messages.getMessage('versiondescription', [], 'package_version_create'),
                longDescription: messages.getMessage('longVersiondescription', [], 'package_version_create'),
                hasValue: true,
                required: false,
                type: 'string'
            }
        ],
        /**
         * the heroku cli hook
         * @param context - the cli context
         * @returns {Promise}
         */
        run(context) {
            const PackageVersionCreateCommand = require(path.join('..', '..', 'lib', 'package', 'packageVersionCreateCommand'));
            return _execCommand(new PackageVersionCreateCommand(), context);
        }
    };
};

//# sourceMappingURL=package_version_create.js.map
