/*
 * Copyright (c) 2016, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root  or https://opensource.org/licenses/BSD-3-Clause
 */
/* eslint global-require: 0 */
'use strict';
const path = require('path');
const messages = require(path.join(__dirname, '..', '..', 'lib', 'messages'))();
const constants = require(path.join(__dirname, '..', '..', 'lib', 'constants'));
module.exports = function (_execCommand) {
    return {
        description: messages.getMessage('cliDescription', [], 'package_version_list'),
        longDescription: messages.getMessage('cliLongDescription', [], 'package_version_list'),
        help: messages.getMessage('help', [], 'package_version_list'),
        requiresProject: false,
        orgType: constants.DEFAULT_DEV_HUB_USERNAME,
        supportsTargetDevHubUsername: true,
        flags: [{
                name: 'createdlastdays',
                char: 'c',
                description: messages.getMessage('createdLastDaysDescription', [], 'packaging'),
                longDescription: messages.getMessage('createdLastDaysLongDescription', [], 'packaging'),
                hasValue: true,
                required: false,
                type: 'number'
            },
            {
                name: 'concise',
                description: messages.getMessage('conciseDescription', [], 'package_version_list'),
                longDescription: messages.getMessage('conciseLongDescription', [], 'package_version_list'),
                hidden: false
            },
            {
                name: 'modifiedlastdays',
                char: 'm',
                description: messages.getMessage('modifiedLastDaysDescription', [], 'packaging'),
                longDescription: messages.getMessage('modifiedLastDaysLongDescription', [], 'packaging'),
                hasValue: true,
                required: false,
                type: 'number'
            },
            {
                name: 'packages',
                char: 'p',
                description: messages.getMessage('packagesDescription', [], 'package_version_list'),
                longDescription: messages.getMessage('packagesLongDescription', [], 'package_version_list'),
                hasValue: true,
                required: false,
                type: 'string',
                array: true
            },
            {
                name: 'released',
                char: 'r',
                description: messages.getMessage('releasedDescription', [], 'package_version_list'),
                longDescription: messages.getMessage('releasedLongDescription', [], 'package_version_list'),
                hasValue: false,
                required: false,
                type: 'flag'
            },
            {
                name: 'orderby',
                char: 'o',
                description: messages.getMessage('orderByDescription', [], 'package_version_list'),
                longDescription: messages.getMessage('orderByLongDescription', [], 'package_version_list'),
                hasValue: true,
                required: false,
                type: 'string',
                array: true
            },
            {
                name: 'verbose',
                description: messages.getMessage('verboseDescription', [], 'package_version_list'),
                longDescription: messages.getMessage('verboseLongDescription', [], 'package_version_list'),
                hidden: false
            }
        ],
        /**
         * the heroku cli hook
         * @param context - the cli context
         * @returns {Promise}
         */
        run(context) {
            const PackageVersionListCommand = require(path.join('..', '..', 'lib', 'package', 'packageVersionListCommand'));
            return _execCommand(new PackageVersionListCommand(), context);
        }
    };
};

//# sourceMappingURL=package_version_list.js.map
