/*
 * Copyright (c) 2016, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root  or https://opensource.org/licenses/BSD-3-Clause
 */
/* eslint global-require: 0 */
'use strict';
const path = require('path');
const messages = require(path.join(__dirname, '..', '..', 'lib', 'messages'))();
const consts = require(path.join(__dirname, '..', '..', 'lib', 'constants'));
module.exports = function (_execCommand) {
    return {
        description: messages.getMessage('cliDescription', [], 'package_version_promote'),
        longDescription: messages.getMessage('cliDescriptionLong', [], 'package_version_promote'),
        help: messages.getMessage('help', [], 'package_version_promote'),
        orgType: consts.DEFAULT_DEV_HUB_USERNAME,
        supportsTargetDevHubUsername: true,
        flags: [
            {
                name: 'package',
                char: 'p',
                description: messages.getMessage('package', [], 'package_version_promote'),
                longDescription: messages.getMessage('packageLong', [], 'package_version_promote'),
                hasValue: true,
                required: true,
                type: 'string'
            },
            {
                name: 'noprompt',
                char: 'n',
                description: messages.getMessage('setasreleasedForce', [], 'package_version_promote'),
                longDescription: messages.getMessage('setasreleasedForceLong', [], 'package_version_promote'),
                hasValue: false,
                required: false,
                type: 'flag;'
            }
        ],
        /**
         * the heroku cli hook
         * @param context - the cli context
         * @returns {Promise}
         */
        run(context) {
            const heroku = require('heroku-cli-util');
            const PackageVersionPromoteCommand = require(path.join('..', '..', 'lib', 'package', 'packageVersionPromoteCommand'));
            const packageVersionPromoteCommand = new PackageVersionPromoteCommand();
            if (context.flags.noprompt) {
                return _execCommand(packageVersionPromoteCommand, context);
            }
            else {
                return heroku.prompt(messages.getMessage('packageVersionPromoteSetAsReleasedYesNo', context.flags.package, 'package_version_promote'), {})
                    .then((answer) => {
                    if (answer.toUpperCase() === 'YES' || answer.toUpperCase() === 'Y') {
                        return _execCommand(packageVersionPromoteCommand, context);
                    }
                    return undefined;
                });
            }
        }
    };
};

//# sourceMappingURL=package_version_promote.js.map
