/*
 * Copyright (c) 2016, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root  or https://opensource.org/licenses/BSD-3-Clause
 */
/* eslint global-require: 0 */
'use strict';
const path = require('path');
const messages = require(path.join(__dirname, '..', '..', 'lib', 'messages'))();
const constants = require(path.join(__dirname, '..', '..', 'lib', 'constants'));
module.exports = function (_execCommand) {
    return {
        description: messages.getMessage('cliDescription', [], 'package_version_update'),
        longDescription: messages.getMessage('cliLongDescription', [], 'package_version_update'),
        help: messages.getMessage('help', [], 'package_version_update'),
        orgType: constants.DEFAULT_DEV_HUB_USERNAME,
        supportsTargetDevHubUsername: true,
        flags: [
            {
                name: 'package',
                char: 'p',
                description: messages.getMessage('package', [], 'package_version_update'),
                longDescription: messages.getMessage('packageLong', [], 'package_version_update'),
                hasValue: true,
                required: true,
                type: 'string'
            },
            {
                name: 'versionname',
                char: 'a',
                description: messages.getMessage('name', [], 'package_version_update'),
                longDescription: messages.getMessage('nameLong', [], 'package_version_update'),
                hasValue: true,
                required: false,
                type: 'string'
            },
            {
                name: 'versiondescription',
                char: 'e',
                description: messages.getMessage('description', [], 'package_version_update'),
                longDescription: messages.getMessage('descriptionLong', [], 'package_version_update'),
                hasValue: true,
                required: false,
                type: 'string'
            },
            {
                name: 'branch',
                char: 'b',
                description: messages.getMessage('branch', [], 'package_version_update'),
                longDescription: messages.getMessage('branchLong', [], 'package_version_update'),
                hasValue: true,
                required: false,
                type: 'string'
            },
            {
                name: 'tag',
                char: 't',
                description: messages.getMessage('tag', [], 'package_version_update'),
                longDescription: messages.getMessage('tagLong', [], 'package_version_update'),
                hasValue: true,
                required: false,
                type: 'string'
            },
            {
                name: 'installationkey',
                char: 'k',
                description: messages.getMessage('key', [], 'package_version_update'),
                longDescription: messages.getMessage('longKey', [], 'package_version_update'),
                hasValue: true,
                required: false,
                type: 'string'
            }
        ],
        /**
         * the heroku cli hook
         * @param context - the cli context
         * @returns {Promise}
         */
        run(context) {
            const PackageVersionUpdateCommand = require(path.join('..', '..', 'lib', 'package', 'packageVersionUpdateCommand'));
            const packageVersionUpdateCommand = new PackageVersionUpdateCommand();
            return _execCommand(packageVersionUpdateCommand, context);
        }
    };
};

//# sourceMappingURL=package_version_update.js.map
