/*
 * Copyright, 1999-2018, salesforce.com
 * All Rights Reserved
 * Company Confidential
 */
'use strict';
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
const sourceApiCommand_1 = require("../../lib/source/sourceApiCommand");
const path = require('path');
const core_1 = require("@salesforce/core");
const consts = require(path.join('..', '..', 'lib', 'constants'));
core_1.Messages.importMessagesDirectory(__dirname);
module.exports = function (_execCommand) {
    const messages = core_1.Messages.loadMessages('salesforce-alm', 'source_delete');
    const commonMsgs = core_1.Messages.loadMessages('salesforce-alm', 'source');
    const { DEFAULT_SRC_WAIT_MINUTES, MIN_SRC_WAIT_MINUTES } = consts;
    return {
        description: messages.getMessage('description'),
        longDescription: messages.getMessage('longDescription'),
        help: messages.getMessage('help'),
        requiresProject: true,
        supportsTargetUsername: true,
        flags: [
            {
                name: 'noprompt',
                char: 'r',
                required: false,
                hidden: false,
                type: 'flag',
                hasValue: false,
                description: messages.getMessage('noPromptParamDescription'),
                longDescription: messages.getMessage('noPromptParamLongDescription')
            },
            {
                name: 'wait',
                char: 'w',
                hasValue: true,
                required: false,
                hidden: false,
                type: 'minutes',
                default: DEFAULT_SRC_WAIT_MINUTES,
                min: MIN_SRC_WAIT_MINUTES,
                description: commonMsgs.getMessage('waitParamDescription', [DEFAULT_SRC_WAIT_MINUTES]),
                longDescription: commonMsgs.getMessage('waitParamDescriptionLong')
            },
            {
                name: 'sourcepath',
                char: 'p',
                hasValue: true,
                required: false,
                hidden: false,
                type: 'filepath',
                array: true,
                description: messages.getMessage('sourcePathDescription'),
                longDescription: messages.getMessage('sourcePathLongDescription'),
                xor: ['metadata']
            },
            {
                name: 'metadata',
                char: 'm',
                description: messages.getMessage('metadataParamDescription'),
                longDescription: messages.getMessage('metadataParamLongDescription'),
                hasValue: true,
                required: false,
                type: 'string',
                array: true
            }
        ],
        /**
         * the heroku cli hook
         * @param context - the cli context
         * @returns {* }
         */
        run(context) {
            return __awaiter(this, void 0, void 0, function* () {
                context.deploytype = sourceApiCommand_1.SourceApiCommand.SOURCE_DEPLOY;
                return yield _execCommand(new sourceApiCommand_1.SourceApiCommand(true), context);
            });
        }
    };
};

//# sourceMappingURL=source_delete.js.map
