"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
/*
 * Copyright (c) 2018, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root  or https://opensource.org/licenses/BSD-3-Clause
 */
const core_1 = require("@salesforce/core");
const consts = require('../../lib/constants');
core_1.Messages.importMessagesDirectory(__dirname);
module.exports = function (_execCommand) {
    const messages = core_1.Messages.loadMessages('salesforce-alm', 'source_retrieve');
    const commonMsgs = core_1.Messages.loadMessages('salesforce-alm', 'source');
    const { DEFAULT_SRC_WAIT_MINUTES, MIN_SRC_WAIT_MINUTES } = consts;
    return {
        command: 'source:retrieve',
        description: messages.getMessage('description'),
        longDescription: messages.getMessage('longDescription'),
        help: messages.getMessage('help'),
        requiresProject: true,
        supportsTargetUsername: true,
        flags: [
            {
                name: 'wait',
                char: 'w',
                hasValue: true,
                required: false,
                hidden: false,
                type: 'minutes',
                default: DEFAULT_SRC_WAIT_MINUTES,
                min: MIN_SRC_WAIT_MINUTES,
                description: commonMsgs.getMessage('waitParamDescription', [DEFAULT_SRC_WAIT_MINUTES]),
                longDescription: commonMsgs.getMessage('waitParamDescriptionLong')
            },
            {
                name: 'manifest',
                char: 'x',
                description: messages.getMessage('manifestParamDescription'),
                longDescription: messages.getMessage('manifestParamLongDescription'),
                hasValue: true,
                required: false,
                type: 'filepath',
                xor: ['metadata', 'sourcepath']
            },
            {
                name: 'metadata',
                char: 'm',
                description: messages.getMessage('metadataParamDescription'),
                longDescription: messages.getMessage('metadataParamLongDescription'),
                hasValue: true,
                required: false,
                type: 'string',
                array: true
            },
            {
                name: 'sourcepath',
                char: 'p',
                description: messages.getMessage('sourcePathParamDescription'),
                longDescription: messages.getMessage('sourcePathParamLongDescription'),
                hasValue: true,
                required: false,
                type: 'filepath',
                array: true
            }
        ],
        run(context) {
            return __awaiter(this, void 0, void 0, function* () {
                const SourceRetrieveCommand = require('../../lib/source/sourceRetrieveCommand').SourceRetrieveCommand;
                return yield _execCommand(new SourceRetrieveCommand(), context);
            });
        }
    };
};

//# sourceMappingURL=source_retrieve.js.map
