"use strict";
/*
 * Copyright (c) 2017, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root  or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
const inFolderDecompositionConfig_1 = require("./inFolderDecompositionConfig");
const customObjectTranslationDecompositionConfig_1 = require("./customObjectTranslationDecompositionConfig");
const describeMetadataDecompositionConfig_1 = require("./describeMetadataDecompositionConfig");
const nonDecomposedContentAndMetadataDecompositionConfig_1 = require("./nonDecomposedContentAndMetadataDecompositionConfig");
const staticResourceDecompositionConfig_1 = require("./staticResourceDecompositionConfig");
class DecompositionConfigFactory {
    static getDecompositionConfig(typeDefObj) {
        if (typeDefObj.metadataName === 'CustomObjectTranslation') {
            return new customObjectTranslationDecompositionConfig_1.CustomObjectTranslationDecompositionConfig(typeDefObj.metadataName, typeDefObj.isGlobal, typeDefObj.isEmptyContainer);
        }
        else if (typeDefObj.metadataName === 'CustomObject') {
            return new describeMetadataDecompositionConfig_1.DescribeMetadataDecompositionConfig(typeDefObj.metadataName, typeDefObj.isGlobal, typeDefObj.isEmptyContainer, true);
        }
        else if (typeDefObj.metadataName === 'StaticResource') {
            return new staticResourceDecompositionConfig_1.StaticResourceDecompositionConfig(typeDefObj.metadataName, typeDefObj.isGlobal, typeDefObj.isEmptyContainer);
        }
        else if (typeDefObj.inFolder) {
            return new inFolderDecompositionConfig_1.InFolderDecompositionConfig(typeDefObj.metadataName, typeDefObj.isGlobal, typeDefObj.isEmptyContainer);
        }
        else {
            return new nonDecomposedContentAndMetadataDecompositionConfig_1.NonDecomposedContentAndMetadataDecompositionConfig(typeDefObj.metadataName, typeDefObj.isGlobal, typeDefObj.isEmptyContainer);
        }
    }
}
exports.DecompositionConfigFactory = DecompositionConfigFactory;

//# sourceMappingURL=decompositionConfigFactory.js.map
