"use strict";
/*
 * Copyright (c) 2017, Salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root  or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
const path = require('path');
const MetadataRegistry = require(path.join(__dirname, '..', 'metadataRegistry'));
const srcDevUtil = require(path.join(__dirname, '..', 'srcDevUtil'));
const sourceState = require(path.join(__dirname, '..', 'sourceState'));
const defaultMetadataType_1 = require("./defaultMetadataType");
class FolderMetadataType extends defaultMetadataType_1.DefaultMetadataType {
    getMdapiFormattedMetadataFileName(metadataFilePath) {
        const fileName = path.basename(metadataFilePath);
        return fileName.replace(`.${this.typeDefObj.ext}`, '');
    }
    getRetrievedMetadataPath(fileProperty, retrieveRoot, bundleFileProperties) {
        let fileName;
        if (fileProperty.fileName.endsWith(MetadataRegistry.getMetadataFileExt())) {
            fileName = fileProperty.fileName;
        }
        else {
            fileName = `${fileProperty.fileName}${MetadataRegistry.getMetadataFileExt()}`;
        }
        const retrievedMetadataPath = path.join(retrieveRoot, fileName);
        return this.validateRetrievedMetadataPathExists(retrievedMetadataPath);
    }
    static createEmptyFolder(workspaceElements, metadataFilePath, ext) {
        if (FolderMetadataType.isCreatingNewFolder(workspaceElements, metadataFilePath)) {
            const folderExtensionIndex = metadataFilePath.indexOf(`.${ext}${MetadataRegistry.getMetadataFileExt()}`);
            const folderPath = metadataFilePath.substring(0, folderExtensionIndex);
            if (!srcDevUtil.pathExistsSync(folderPath)) {
                srcDevUtil.ensureDirectoryExistsSync(folderPath);
                return folderPath;
            }
        }
        return null;
    }
    /**
     * Returns true if a new folder type is being created; false if a folder type is being deleted or changed
     * @param workspaceElements
     * @param {string} metadataFilePath
     * @returns {boolean}
     */
    static isCreatingNewFolder(workspaceElements, metadataFilePath) {
        const metadataFileElement = workspaceElements.find(workspaceElement => workspaceElement.getSourcePath() === metadataFilePath);
        if (metadataFileElement) {
            return metadataFileElement.getState() === sourceState.NEW;
        }
        return false;
    }
    isFolderType() {
        return true;
    }
}
exports.FolderMetadataType = FolderMetadataType;

//# sourceMappingURL=folderMetadataType.js.map
