"use strict";
/*
 * Copyright (c) 2017, Salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root  or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
const path = require('path');
const defaultMetadataType_1 = require("./defaultMetadataType");
const PathUtil = require("../sourcePathUtil");
const MetadataRegistry = require(path.join(__dirname, '..', 'metadataRegistry'));
class InFolderMetadataType extends defaultMetadataType_1.DefaultMetadataType {
    getFullNameFromFilePath(filePath) {
        return this.getAggregateFullNameFromFilePath(filePath);
    }
    getAggregateFullNameFromFilePath(filePath) {
        const parentFolder = PathUtil.getParentDirectoryName(filePath);
        const fileName = PathUtil.getFileName(filePath);
        return path.join(parentFolder, fileName);
    }
    getDefaultAggregateMetadataPath(fullName, defaultSourceDir, bundleFileProperties) {
        const pathToDefaultTypeDir = path.join(defaultSourceDir, this.typeDefObj.defaultDirectory);
        const [folderName, fileNameWithoutExtensions] = fullName.split(path.sep);
        const fileName = `${fileNameWithoutExtensions}.${this.typeDefObj.ext}${MetadataRegistry.getMetadataFileExt()}`;
        return path.join(pathToDefaultTypeDir, folderName, fileName);
    }
    getPathToMdapiSourceDir(aggregateFullName, mdDir) {
        return path.join(mdDir, this.typeDefObj.defaultDirectory, aggregateFullName.split(path.sep)[0]);
    }
    getAggregateFullNameFromMdapiPackagePath(mdapiPackagePath) {
        const pathElements = mdapiPackagePath.split(path.sep);
        let fullName = pathElements[1];
        if (pathElements.length === 3) { // includes container dir
            fullName = path.join(pathElements[1], PathUtil.getFileName(pathElements[2]));
        }
        return fullName;
    }
    getAggregateFullNameFromSourceMemberName(sourceMemberName) {
        return sourceMemberName;
    }
    sourceMemberFullNameCorrespondsWithWorkspaceFullName(sourceMemberFullName, workspaceFullName) {
        return sourceMemberFullName === workspaceFullName;
    }
    handleSlashesForSourceMemberName(sourceMemberFullName) {
        return PathUtil.replaceForwardSlashes(sourceMemberFullName);
    }
}
exports.InFolderMetadataType = InFolderMetadataType;

//# sourceMappingURL=inFolderMetadataType.js.map
