"use strict";
/*
 * Copyright (c) 2017, Salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root  or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
const path = require('path');
const defaultMetadataType_1 = require("./defaultMetadataType");
const PathUtil = require("../sourcePathUtil");
const bundlePathHelper_1 = require("../bundlePathHelper");
class LightningComponentBundleMetadataType extends defaultMetadataType_1.DefaultMetadataType {
    constructor(typeDefObj) {
        super(typeDefObj);
    }
    getFullNameFromFilePath(filePath) {
        return bundlePathHelper_1.BundlePathHelper.buildFullNameFromFilePath(filePath, this.typeDefObj.defaultDirectory);
    }
    getAggregateFullNameFromFilePath(filePath) {
        return bundlePathHelper_1.BundlePathHelper.scanFilePathForAggregateFullName(filePath, this.typeDefObj.defaultDirectory);
    }
    getAggregateMetadataFilePathFromWorkspacePath(filePath) {
        return bundlePathHelper_1.BundlePathHelper.findMetadataFilePathInBundleDir(filePath, this.typeDefObj.defaultDirectory);
    }
    getDefaultAggregateMetadataPath(fullName, defaultSourceDir, bundleFileProperties) {
        return bundlePathHelper_1.BundlePathHelper.getPathFromBundleTypeFileProperties(fullName, defaultSourceDir, this.typeDefObj.defaultDirectory, bundleFileProperties);
    }
    getAggregateFullNameFromSourceMemberName(sourceMemberName) {
        return sourceMemberName.split(path.sep)[0];
    }
    getAggregateFullNameFromWorkspaceFullName(workspaceFullName) {
        return workspaceFullName.split(path.sep)[0];
    }
    getPathToMdapiSourceDir(aggregateFullName, mdDir) {
        return path.join(mdDir, this.typeDefObj.defaultDirectory, aggregateFullName);
    }
    getOriginContentPathsForSourceConvert(metadataFilePath, workspaceVersion, unsupportedMimeTypes, forceIgnore) {
        const bundleDirPath = path.dirname(metadataFilePath);
        return Promise.resolve(bundlePathHelper_1.BundlePathHelper.getAllNestedBundleContentPaths(bundleDirPath, forceIgnore));
    }
    getAggregateFullNameFromComponentFailure(componentFailure) {
        // if it's an LWC-related error, the fullame is the name of the file within the bundle without any extension
        // for example for a bundle with fullname=testbundle and an error in the helper the MD API response will contain:
        // "fileName": "metadataPackage_1497651865666/lightningcomponents/testbundle/subfolder/testbundle.js",
        // "fullName": "testbundle",
        return this.getAggregateFullNameFromFilePath(componentFailure.fileName);
    }
    getWorkspaceFullNameFromComponentFailure(componentFailure) {
        return this.getFullNameFromFilePath(componentFailure.fileName);
    }
    getMdapiFormattedContentFileName(originContentPath, aggregateFullName) {
        // LWC bundles can have nested sub-directories.
        // In order maintain the bundle structure in the mdapi formatted directory,
        // return the path from the bundle directory to the file
        const pathToBundle = PathUtil.getPathToDir(originContentPath, aggregateFullName);
        return path.relative(pathToBundle, originContentPath);
    }
    handleSlashesForSourceMemberName(sourceMemberFullName) {
        return PathUtil.replaceForwardSlashes(sourceMemberFullName);
    }
    sourceMemberFullNameCorrespondsWithWorkspaceFullName(sourceMemberFullName, workspaceFullName) {
        return sourceMemberFullName === workspaceFullName;
    }
}
exports.LightningComponentBundleMetadataType = LightningComponentBundleMetadataType;

//# sourceMappingURL=lightningComponentBundleMetadataType.js.map
