"use strict";
/*
 * Copyright (c) 2016, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root  or https://opensource.org/licenses/BSD-3-Clause
 * This module hooks into HttpApi request to get perfMetrics from the response header then returns the original request back.
 */
Object.defineProperty(exports, "__esModule", { value: true });
const HttpApi = require("jsforce/lib/http-api");
let request = HttpApi.prototype.request;
const requestPerfMetrics = [];
function getPerfMetricsFromResponse(response) {
    let metrics = response.headers['perfmetrics'];
    /* istanbul ignore else */
    if (metrics) {
        let perfMetrics = {
            requestPath: response.req.path,
            perfMetrics: JSON.parse(metrics)
        };
        requestPerfMetrics.push(perfMetrics);
    }
}
HttpApi.prototype.request = function (req, ...args) {
    this.on('response', getPerfMetricsFromResponse);
    return request.call(this, req, ...args);
};
module.exports = { request, requestPerfMetrics, getPerfMetricsFromResponse };

//# sourceMappingURL=perfMetricsRequest.js.map
