/*
 * Copyright (c) 2016, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root  or https://opensource.org/licenses/BSD-3-Clause
 */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const Promise = require("bluebird");
const orgSnapshotApi_1 = require("./orgSnapshotApi");
const messages = require(path.join(__dirname, '..', '..', 'lib', 'messages'))();
const logger = require(path.join(__dirname, '..', 'logApi'));
/**
 * Get a Org Snapshot record.
 */
class OrgSnapshotGetCommand {
    constructor() {
        this.logger = logger.child('org:snapshot:get');
    }
    validate(context) {
        // framework handles required params
        return Promise.resolve(context);
    }
    execute(context) {
        // double-check
        if (!context.flags.snapshot) {
            throw new Error(messages.getMessage('snapshotInvalid', [], 'orgSnapshot'));
        }
        this.orgSnapshotIdOrName = context.flags.snapshot;
        return orgSnapshotApi_1.OrgSnapshotApiImpl.create(context.org)
            .then(orgSnapshotApi => {
            this.orgSnapshotApi = orgSnapshotApi;
            return this.orgSnapshotApi.get(this.orgSnapshotIdOrName);
        });
    }
    /**
     * returns a human readable message for a cli output
     * @param result - the data representing the Org Snapshot
     * @returns {string}
     */
    getHumanSuccessMessage(result) {
        const data = this.orgSnapshotApi.mapDataToLabel(result);
        if (result.Status === 'Error') {
            data.push({ name: 'Error', value: result.Error || 'Unknown' });
        }
        this.logger.styledHeader(this.logger.color.blue('Org Snapshot'));
        this.logger.table(data, { columns: [
                { key: 'name', label: 'Name' },
                { key: 'value', label: 'Value' }
            ] });
        return '';
    }
}
module.exports = OrgSnapshotGetCommand;

//# sourceMappingURL=orgSnapshotGetCommand.js.map
