/*
 * Copyright (c) 2016, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root  or https://opensource.org/licenses/BSD-3-Clause
 */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const Promise = require("bluebird");
const orgSnapshotApi_1 = require("./orgSnapshotApi");
const logger = require(path.join(__dirname, '..', 'logApi'));
/**
 * List Org Snapshots linked DevHub.
 */
class OrgSnapshotListCommand {
    constructor() {
        this.logger = logger.child('org:snapshot:list');
        this.records = [];
    }
    validate(context) {
        return Promise.resolve(context);
    }
    execute(context) {
        return orgSnapshotApi_1.OrgSnapshotApiImpl.create(context.org)
            .then(orgSnapshotApi => orgSnapshotApi.list())
            .then((records) => {
            this.records = records;
            return records;
        });
    }
    /**
     * returns a human readable message for a cli output
     * @param result - the data representing the Org Snapshot
     * @returns {string}
     */
    getColumnData() {
        this.logger.styledHeader(this.logger.color.blue(`Org Snapshots [${this.records.length}]`));
        return orgSnapshotApi_1.ORG_SNAPSHOT_COLUMNS;
    }
}
module.exports = OrgSnapshotListCommand;

//# sourceMappingURL=orgSnapshotListCommand.js.map
